@@ -1,5 +1,5 @@
 use rsvg::test_utils::reference_utils::{Compare, Evaluate, Reference};
-use rsvg::test_utils::{load_svg, render_document, SurfaceSize};
+use rsvg::test_utils::{SurfaceSize, load_svg, render_document};
 use rsvg::{test_compare_render_output, test_svg_reference};
 
 #[test]
